import withPreparedProps from 'hoc/withPreparedProps';
import Breadcrumbs from 'components/Breadcrumbs';
import Listing from 'layout/ListingLayout';
import {useTranslation} from 'react-i18next';
import Button from 'components/Button';
import {FilterIcon} from '@heroicons/react/solid';
import {Link, generatePath, useNavigate} from 'react-router-dom';
import {useMemo, useEffect} from 'react';
import {alt} from 'crocks/pointfree';
import {isEmpty, not, identity, getProp, chain, safe, map, objOf, Maybe, getPropOr, pipe, curry} from 'crocks';
import {useFilter} from 'hook/useFilter';
import {useCompanies} from '../api';
//import { CompanyCreateRoute, CompanyEditRoute } from '../routes';
import { format } from 'date-fns';

const getColumn = curry((t, Component, key, pred, mapper, status, isSortable) => ({
    Component,
    headerText: t(key),
    key,
    status,
    isSortable,
    itemToProps: item => pipe(
        getProp(key),
        chain(safe(pred)),
        map(mapper),
        map(objOf('children')),
        map(a => ({...item, ...a})),
        alt(Maybe.Just(item)),
    )(item),
  }));

const CompaniesListLayout = withPreparedProps(Listing, () => {
    const nav = useNavigate();
    const {t: tb} = useTranslation('company', {keyPrefix: 'breadcrumbs'});
    const {t: tl} = useTranslation('company', {keyPrefix: 'list'});
    const {t: tc} = useTranslation('company', {keyPrefix: 'list.column'});

    const notEmpty = not(isEmpty)
    const dateCol = (d) => format(new Date(d), 'Y-MM-dd HH:mm');


    const column = useMemo(() => getColumn(tc, props => (
        <Link to={'#'}> {/* generatePath(CompaniesEditRoute.props.path, { id: props?.id }) */}
            {props?.children}
        </Link>
      )), [tc]);

    const tableColumns = [
        column('id', notEmpty, identity, true, true),
        column('cid', notEmpty, identity, true, true),
        column('name', notEmpty, identity, true, true),
    ];

    const filtersData = [
        
    ];

    const [queryParams, filters, columns, defaultFilter, toggleFilter, setExportData, sortColumnKey, setSortColumn, dispatch] = useFilter(
        'company',
        tableColumns,
        filtersData,
        {canArchive: true},
      );

    const api = useCompanies({filters: queryParams})

    useEffect(() => {
      api.mutate()
      setExportData(api.data);
    }, [queryParams, sortColumnKey]);

    // search
    const onApiQuery = (query) => dispatch({type: 'TEXT', value: `%${query}%`, key: 'name'});
 
    return {
        api,
        onApiQuery,
        list: api?.data?.flat() ?? [],
        rowKeyLens: getPropOr(0, 'id'),
        breadcrumbs: (
            <Breadcrumbs>
                <Breadcrumbs.Item><span className='font-semibold'>{tb`Companies`}</span></Breadcrumbs.Item>
                <Breadcrumbs.Item hideSlash>
                    <Button.NoBg onClick={toggleFilter}>
                        {defaultFilter.id ? defaultFilter.name : tb`AllData` } 
                        <FilterIcon className='w-6 h-6 ml-2 text-gray-300 cursor-pointer inline-block focus:ring-0' />
                    </Button.NoBg>
                </Breadcrumbs.Item>
            </Breadcrumbs>
        ),
        buttons: (
            <>
              {/* <Button onClick={() => nav(CompaniesCreateRoute.props.path)}>{tl`create`}</Button> */}
            </>
        ),
        innerlinks: (
            <></>
        ),
        filters,
        tableColumns,
        columns,
        sortColumnKey,
        setSortColumn,
    }
})

export default CompaniesListLayout
